@@ -1,11 +1,11 @@
 # lifted from github.com/wandb/sweeps
 
 import json
-import jsonschema
-from jsonschema import Draft7Validator, validators
-
 from pathlib import Path
 
+import jsonschema  # type:ignore
+from jsonschema import Draft7Validator
+
 testlib_config_jsonschema_fname = Path(__file__).parent / "schema-wandb-testlib.json"
 with open(testlib_config_jsonschema_fname, "r") as f:
     testlib_config_jsonschema = json.load(f)
